==> nextcloud-26.0.11.tgz: nextcloud/apps/systemtags/l10n/th.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "แท็กระบบ %1$s ถูกเพิ่มโดยระบบ",
    "Added system tag {systemtag}" : "เพิ่มแท็กระบบ {systemtag} แล้ว",
    "Added system tag %1$s" : "เพิ่มแท็กระบบ %1$s แล้ว",
    "%1$s added system tag %2$s" : "%1$s ได้เพิ่มแท็กระบบ %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ได้เพิ่มแท็กระบบ {systemtag}",
    "System tag %1$s removed by the system" : "แท็กระบบ %1$s ถูกเอาออกโดยระบบ",
    "Removed system tag {systemtag}" : "เอาแท็กระบบ {systemtag} ออกแล้ว",
    "Removed system tag %1$s" : "เอาแท็กระบบ %1$s ออกแล้ว",
    "%1$s removed system tag %2$s" : "%1$s ได้เอาแท็กระบบ %2$s ออก",
    "{actor} removed system tag {systemtag}" : "{actor} ได้เอาแท็กระบบ {systemtag} ออก",
    "You created system tag %1$s" : "คุณได้เพิ่มแท็กระบบ %1$s",
    "You created system tag {systemtag}" : "คุณได้เพิ่มแท็กระบบ {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ได้สร้างแท็กระบบ %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ได้เพิ่มแท็กระบบ {systemtag}",
    "You deleted system tag %1$s" : "คุณได้ลบแท็กระบบ %1$s",
    "You deleted system tag {systemtag}" : "คุณได้ลบแท็กระบบ {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ได้ลบแท็กระบบ %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ได้ลบแท็กระบบ {systemtag}",
    "You updated system tag %2$s to %1$s" : "คุณได้อัปเดตแท็กระบบจาก %2$s เป็น %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "คุณได้อัปเดตแท็กระบบจาก {oldsystemtag} เป็น {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ได้อัปเดตแท็กระบบจาก %3$s เป็น %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ได้อัปเดตแท็กระบบจาก {oldsystemtag} เป็น {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "แท็กระบบ %2$s ถูกเพิ่มไปยัง %1$s โดยระบบ",
    "System tag {systemtag} was added to {file} by the system" : "แท็กระบบ {systemtag} ถูกเพิ่มไปยัง {file} โดยระบบ",
    "You added system tag %2$s to %1$s" : "คุณได้เพิ่มแท็กระบบ %2$sไปยัง %1$s",
    "You added system tag {systemtag} to {file}" : "คุณได้เพิ่มแท็กระบบ {systemtag} ไปยัง {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ได้เพิ่มแท็กระบบ %3$s ไปยัง %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ได้เพิ่มแท็กระบบ {systemtag} ไปยัง {file}",
    "System tag %2$s was removed from %1$s by the system" : "แท็กระบบ %2$s ถูกเอาออกจาก %1$s โดยระบบ",
    "System tag {systemtag} was removed from {file} by the system" : "แท็กระบบ {systemtag} ถูกเอาออกจาก {file} โดยระบบ",
    "You removed system tag %2$s from %1$s" : "คุณได้เอาแท็กระบบ %2$sออกจาก %1$s",
    "You removed system tag {systemtag} from {file}" : "คุณได้เอาแท็กระบบ {systemtag} ออกจาก {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ได้เอาแท็กระบบ %3$s ออกจาก %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ได้เอาแท็กระบบ {systemtag} ออกจาก {file}",
    "%s (restricted)" : "%s (ถูกจำกัด)",
    "%s (invisible)" : "%s (ไม่แสดงสถานะ)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>แท็กระบบ</strong> สำหรับไฟล์ที่ได้รับการแก้ไข",
    "Tags" : "แท็ก",
    "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
    "Collaborative tagging functionality which shares tags among users." : "คุณสมบัติแท็กแบบทำงานร่วมกัน ซึ่งใช้แท็กร่วมกันระหว่างผู้ใช้หลายคน",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "คุณสมบัติแท็กแบบทำงานร่วมกัน ซึ่งใช้แท็กร่วมกันระหว่างผู้ใช้หลายคน ดีสำหรับทีม\n\t(หากคุณเป็นผู้ให้บริการที่มีการติดตั้งแบบเช่าหลายคน ควรปิดใช้งานแอปนี้ เนื่องจากมีการใช้แท็กร่วมกันอยู่แล้ว)",
    "Create" : "สร้าง",
    "Update" : "อัปเดต",
    "Delete" : "ลบ",
    "Reset" : "ตั้งค่าใหม่",
    "Public" : "สาธารณะ",
    "Restricted" : "ถูกจำกัด",
    "Invisible" : "มองไม่เห็น",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "ผู้ใช้ทุกคนสามารถใช้แท็กแบบทำงานร่วมกันได้ แท็กที่ถูกจำกัดสามารถมองเห็นได้โดยผู้ใช้ แต่ผู้ใช้ไม่สามารถจัดสรรได้ แท็กที่มองไม่เห็นใช้สำหรับภายใน เนื่องจากผู้ใช้ไม่สามารถเห็นหรือจัดสรรแท็กเหล่านั้น",
    "No tags found" : "ไม่พบแท็ก",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขเมื่อ",
    "Tag name is empty" : "ชื่อแท็กว่าง",
    "Select tag …" : "เลือกแท็ก …",
    "Tagged files" : "ไฟล์ที่ติดแท็ก",
    "Select tags to filter by" : "เลือกแท็กที่จะกรอง",
    "Please select tags to filter by" : "กรุณาเลือกแท็กที่จะกรอง",
    "No files found for the selected tags" : "ไม่พบไฟล์สำหรับแท็กที่เลือก",
    "Create a new tag" : "สร้างแท็กใหม่"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.9.tgz: nextcloud/apps/systemtags/l10n/th.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "แท็กระบบ %1$s ถูกเพิ่มโดยระบบ",
    "Added system tag {systemtag}" : "เพิ่มแท็กระบบ {systemtag} แล้ว",
    "Added system tag %1$s" : "เพิ่มแท็กระบบ %1$s แล้ว",
    "%1$s added system tag %2$s" : "%1$s ได้เพิ่มแท็กระบบ %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ได้เพิ่มแท็กระบบ {systemtag}",
    "System tag %1$s removed by the system" : "แท็กระบบ %1$s ถูกเอาออกโดยระบบ",
    "Removed system tag {systemtag}" : "เอาแท็กระบบ {systemtag} ออกแล้ว",
    "Removed system tag %1$s" : "เอาแท็กระบบ %1$s ออกแล้ว",
    "%1$s removed system tag %2$s" : "%1$s ได้เอาแท็กระบบ %2$s ออก",
    "{actor} removed system tag {systemtag}" : "{actor} ได้เอาแท็กระบบ {systemtag} ออก",
    "You created system tag %1$s" : "คุณได้เพิ่มแท็กระบบ %1$s",
    "You created system tag {systemtag}" : "คุณได้เพิ่มแท็กระบบ {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ได้สร้างแท็กระบบ %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ได้เพิ่มแท็กระบบ {systemtag}",
    "You deleted system tag %1$s" : "คุณได้ลบแท็กระบบ %1$s",
    "You deleted system tag {systemtag}" : "คุณได้ลบแท็กระบบ {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ได้ลบแท็กระบบ %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ได้ลบแท็กระบบ {systemtag}",
    "You updated system tag %2$s to %1$s" : "คุณได้อัปเดตแท็กระบบจาก %2$s เป็น %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "คุณได้อัปเดตแท็กระบบจาก {oldsystemtag} เป็น {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ได้อัปเดตแท็กระบบจาก %3$s เป็น %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ได้อัปเดตแท็กระบบจาก {oldsystemtag} เป็น {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "แท็กระบบ %2$s ถูกเพิ่มไปยัง %1$s โดยระบบ",
    "System tag {systemtag} was added to {file} by the system" : "แท็กระบบ {systemtag} ถูกเพิ่มไปยัง {file} โดยระบบ",
    "You added system tag %2$s to %1$s" : "คุณได้เพิ่มแท็กระบบ %2$sไปยัง %1$s",
    "You added system tag {systemtag} to {file}" : "คุณได้เพิ่มแท็กระบบ {systemtag} ไปยัง {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ได้เพิ่มแท็กระบบ %3$s ไปยัง %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ได้เพิ่มแท็กระบบ {systemtag} ไปยัง {file}",
    "System tag %2$s was removed from %1$s by the system" : "แท็กระบบ %2$s ถูกเอาออกจาก %1$s โดยระบบ",
    "System tag {systemtag} was removed from {file} by the system" : "แท็กระบบ {systemtag} ถูกเอาออกจาก {file} โดยระบบ",
    "You removed system tag %2$s from %1$s" : "คุณได้เอาแท็กระบบ %2$sออกจาก %1$s",
    "You removed system tag {systemtag} from {file}" : "คุณได้เอาแท็กระบบ {systemtag} ออกจาก {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ได้เอาแท็กระบบ %3$s ออกจาก %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ได้เอาแท็กระบบ {systemtag} ออกจาก {file}",
    "%s (restricted)" : "%s (ถูกจำกัด)",
    "%s (invisible)" : "%s (ไม่แสดงสถานะ)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>แท็กระบบ</strong> สำหรับไฟล์ที่ได้รับการแก้ไข",
    "Tags" : "แท็ก",
    "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
    "Create" : "สร้าง",
    "Update" : "อัปเดต",
    "Delete" : "ลบ",
    "Reset" : "ตั้งค่าใหม่",
    "Public" : "สาธารณะ",
    "Restricted" : "ถูกจำกัด",
    "Invisible" : "มองไม่เห็น",
    "No tags found" : "ไม่พบแท็ก",
    "Cancel" : "ยกเลิก",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "ผู้ใช้ทุกคนสามารถใช้แท็กแบบทำงานร่วมกันได้ แท็กที่ถูกจำกัดสามารถมองเห็นได้โดยผู้ใช้ แต่ผู้ใช้ไม่สามารถจัดสรรได้ แท็กที่มองไม่เห็นใช้สำหรับภายใน เนื่องจากผู้ใช้ไม่สามารถเห็นหรือจัดสรรแท็กเหล่านั้น",
    "Collaborative tagging functionality which shares tags among users." : "คุณสมบัติแท็กแบบทำงานร่วมกัน ซึ่งใช้แท็กร่วมกันระหว่างผู้ใช้หลายคน",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "คุณสมบัติแท็กแบบทำงานร่วมกัน ซึ่งใช้แท็กร่วมกันระหว่างผู้ใช้หลายคน ดีสำหรับทีม\n\t(หากคุณเป็นผู้ให้บริการที่มีการติดตั้งแบบเช่าหลายคน ควรปิดใช้งานแอปนี้ เนื่องจากมีการใช้แท็กร่วมกันอยู่แล้ว)",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขเมื่อ"
},
"nplurals=1; plural=0;");
